if (getRversion() >= "3.1.0") {
  utils::globalVariables(
    c(
      ".",
      "agency_id",
      "color",
      "df_name",
      "departures",
      "field_provided_status",
      "field_spec",
      "field",
      "file_provided_status",
      "file_spec",
      "lat",
      "lng",
      "loc_lat",
      "loc_lng",
      "n",
      "opacity",
      "popups",
      "route_id",
      "route_short_name",
      "service_id",
      "shape_id",
      "shape_pt_lat",
      "shape_pt_lon",
      "shape_pt_sequence",
      "spec",
      "stop_id",
      "stop_lat",
      "stop_lon",
      "stop_name",
      "trip_id",
      "validation_details",
      "validation_status",
      "provided_status",
      "loc_lat",
      "loc_lng",
      "median_headways", 
      "mean_headways", 
      "st_dev_headways", 
      "stop_count",
      "bool",
      "start_date",
      "end_date",
      "weekday",
      "exception_type",
      "arrival_time",
      "departure_time",
      "start_time",
      "end_time",
      "feed_start_date",
      "feed_end_date",
      "between"
    )
  )
}